@@ -37,12 +37,12 @@
 
 #ifndef __attribute__
 /* This feature is available in gcc versions 2.5 and later.  */
-# if __GNUC__ < 2 || (__GNUC__ == 2 && __GNUC_MINOR__ < 5) || __STRICT_ANSI__
+# if __GNUC__ < 2 || (__GNUC__ == 2 && __GNUC_MINOR__ < 5)
 #  define __attribute__(Spec) /* empty */
 # endif
 /* The __-protected variants of `format' and `printf' attributes
    are accepted by gcc versions 2.6.4 (effectively 2.7) and later.  */
-# if __GNUC__ < 2 || (__GNUC__ == 2 && __GNUC_MINOR__ < 7) || __STRICT_ANSI__
+# if __GNUC__ < 2 || (__GNUC__ == 2 && __GNUC_MINOR__ < 7)
 #  define __format__ format
 #  define __printf__ printf
 # endif
@@ -278,7 +278,7 @@ struct argp
 };
 
 /* Possible KEY arguments to a help filter function.  */
-#define ARGP_KEY_HELP_PRE_DOC	0x2000001 /* Help text preceeding options. */
+#define ARGP_KEY_HELP_PRE_DOC	0x2000001 /* Help text preceding options. */
 #define ARGP_KEY_HELP_POST_DOC	0x2000002 /* Help text following options. */
 #define ARGP_KEY_HELP_HEADER	0x2000003 /* Option header string. */
 #define ARGP_KEY_HELP_EXTRA	0x2000004 /* After all other documentation;
@@ -506,7 +506,7 @@ extern void __argp_help (const struct argp *__restrict __argp,
    parsing routine (thus taking an argp_state structure as the first
    argument).  They may or may not print an error message and exit, depending
    on the flags in STATE -- in any case, the caller should be prepared for
-   them *not* to exit, and should return an appropiate error after calling
+   them *not* to exit, and should return an appropriate error after calling
    them.  [argp_usage & argp_error should probably be called argp_state_...,
    but they're used often enough that they should be short]  */
 
@@ -520,8 +520,8 @@ extern void __argp_state_help (const struct argp_state *__restrict __state,
 			       unsigned int __flags);
 
 /* Possibly output the standard usage message for ARGP to stderr and exit.  */
-extern void argp_usage (const struct argp_state *__state);
-extern void __argp_usage (const struct argp_state *__state);
+/* extern void argp_usage (const struct argp_state *__state); */
+/* extern void __argp_usage (const struct argp_state *__state); */
 
 /* If appropriate, print the printf string FMT and following args, preceded
    by the program name and `:', to stderr, and followed by a `Try ... --help'
@@ -550,14 +550,25 @@ extern void __argp_failure (const struct argp_state *__restrict __state,
 			    const char *__restrict __fmt, ...)
      __attribute__ ((__format__ (__printf__, 4, 5)));
 
+# ifndef ARGP_EI
+#  define ARGP_EI static __inline__
+#  define __ARG_UP /* nothing */
+# else
+#  define __ARG_UP __THROW
+# endif
+
 /* Returns true if the option OPT is a valid short option.  */
-extern int _option_is_short (const struct argp_option *__opt) __THROW;
-extern int __option_is_short (const struct argp_option *__opt) __THROW;
+ARGP_EI int _option_is_short (const struct argp_option *__opt) __ARG_UP;
+#if defined(__USE_EXTERN_INLINES) && !_LIBC
+/* ARGP_EI int __option_is_short (const struct argp_option *__opt) __ARG_UP; */
+#endif
 
 /* Returns true if the option OPT is in fact the last (unused) entry in an
    options array.  */
-extern int _option_is_end (const struct argp_option *__opt) __THROW;
-extern int __option_is_end (const struct argp_option *__opt) __THROW;
+ARGP_EI int _option_is_end (const struct argp_option *__opt) __ARG_UP;
+#if defined(__USE_EXTERN_INLINES) && !_LIBC
+/* ARGP_EI int __option_is_end (const struct argp_option *__opt) __ARG_UP; */
+#endif
 
 /* Return the input field for ARGP in the parser corresponding to STATE; used
    by the help routines.  */
@@ -577,10 +588,6 @@ extern void *__argp_input (const struct argp *__restrict __argp,
 #  define __option_is_end _option_is_end
 # endif
 
-# ifndef ARGP_EI
-#  define ARGP_EI extern __inline__
-# endif
-
 ARGP_EI void
 __argp_usage (const struct argp_state *__state)
 {
@@ -588,7 +595,7 @@ __argp_usage (const struct argp_state *__state)
 }
 
 ARGP_EI int
-__NTH (__option_is_short (const struct argp_option *__opt))
+(__option_is_short (const struct argp_option *__opt))
 {
   if (__opt->flags & OPTION_DOC)
     return 0;
@@ -600,7 +607,7 @@ __NTH (__option_is_short (const struct argp_option *__opt))
 }
 
 ARGP_EI int
-__NTH (__option_is_end (const struct argp_option *__opt))
+(__option_is_end (const struct argp_option *__opt))
 {
   return !__opt->key && !__opt->name && !__opt->doc && !__opt->group;
 }
