@@ -1,6 +1,7 @@
 /*
  * Blame - An RCS file annotator
  * Copyright (C) 2004, 2005  Michael Chapman
+ * Copyright 2024 Thomas E. Dickey
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -38,12 +39,12 @@
 /*
  * Program name for errors.
  */
-const char *program_name;
+extern const char *program_name;
 
 /*
  * Package name/bug address for argp
  */
-const char *argp_program_version = PACKAGE_STRING "; emulating RCS version 5";
+const char *argp_program_version = PACKAGE_STRING " (" PACKAGE_DATE "); emulating RCS version 5";
 const char *argp_program_bug_address = "<" PACKAGE_BUGREPORT ">";
 
 /*
@@ -135,7 +136,7 @@ annotate_revision(const char *filename, const rcs_t *rcs, const char *rev) {
 	assert(dot); /* since rcs_rev_is_valid(rev) */
 	dot = strchrnul(dot + 1, '.');
 	*dot = '\0';
-	length = dot - copy;
+	length = (size_t) (dot - copy);
 	
 	/*
 	 * Start from the head revision.
@@ -236,7 +237,7 @@ annotate_revision(const char *filename, const rcs_t *rcs, const char *rev) {
 		*dot = '.';
 		dot = strchrnul(dot + 1, '.');
 		*dot = '\0';
-		length = dot - copy;
+		length = (size_t) (dot - copy);
 		
 		/*
 		 * Continue along this branch until we find the correct revision or another
@@ -424,9 +425,10 @@ parse_options(int key, char *arg, struct argp_state *state) {
 			switch (*arg) {
 			case '3': case '4': case '5':
 				if (!*(arg + 1)) {
-					rcs_emulation = *arg - '0';
+					rcs_emulation = (unsigned) (*arg - '0');
 					break;
 				}
+				/* FALLTHRU */
 			default:
 				argp_failure(
 					state, EXIT_FAILURE, 0,
