@@ -25,12 +25,12 @@
 #define TM_UNDEFINED_ZONE ((long) -24 * 60 * 60)
 #define TM_LOCAL_ZONE (TM_UNDEFINED_ZONE - 1)
 
-const char * date_parse_zone PARAMS((const char *, long *));
-time_t date_parse PARAMS((const char *, int, long));
-time_t date_parse_rev PARAMS((const char *));
+const char * date_parse_zone (const char *, long *);
+time_t date_parse (const char *, int, long);
+time_t date_parse_rev (const char *);
 
-char * date_format PARAMS((time_t));
-char * date_sprintf PARAMS((time_t, long));
-size_t date_sprintf_prefix PARAMS((time_t, char *, size_t));
+char * date_format (time_t);
+char * date_sprintf (time_t, long);
+size_t date_sprintf_prefix (time_t, char *, size_t);
 
 #endif /* _DATE_H */
